@@ -1,8 +1,8 @@
 /**
  * This file is a part of Qtpfsgui package.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
  */
@@ -26,6 +26,10 @@
 
 #include <QSettings>
 extern QSettings settings;
-QString saveLDRImage(const QString initialFileName, const QImage* image);
+QString saveLDRImage(const QString initialFileName, const QImage* image, bool batchMode = false);
+bool matchesLdrFilename(QString file);
+bool matchesHdrFilename(QString file);
+bool matchesValidHDRorLDRfilename(QString file);
+QStringList convertUrlListToFilenameList(QList<QUrl> urls);
 
 #endif
