@@ -79,7 +79,29 @@ void ExifOperations::copyExifData(const std::string& from, const std::string& to
 	destimage->writeMetadata();
 }
 
-float ExifOperations::obtain_expotime(const std::string& filename) {
+/**
+ * This function obtains the "average scene luminance" (cd/m^2) from an image file.
+ * "average scene luminance" is the L (aka B) value mentioned in [1]
+ * You have to take a log2f of the returned value to get an EV value.
+ * 
+ * We are using K=12.07488f and the exif-implied value of N=1/3.125 (see [1]).
+ * K=12.07488f is the 1.0592f * 11.4f value in pfscalibration's pfshdrcalibrate.cpp file.
+ * Based on [3] we can say that the value can also be 12.5 or even 14.
+ * Another reference for APEX is [4] where N is 0.3, closer to the APEX specification of 2^(-7/4)=0.2973.
+ * 
+ * [1] http://en.wikipedia.org/wiki/APEX_system
+ * [2] http://en.wikipedia.org/wiki/Exposure_value
+ * [3] http://en.wikipedia.org/wiki/Light_meter
+ * [4] http://doug.kerr.home.att.net/pumpkin/#APEX
+ * 
+ * This function tries first to obtain the shutter speed from either of
+ * two exif tags (there is no standard between camera manifacturers):
+ * ExposureTime or ShutterSpeedValue.
+ * Same thing for f-number: it can be found in FNumber or in ApertureValue.
+ * 
+ * F-number and shutter speed are mandatory in exif data for EV calculation, iso is not.
+ */
+float ExifOperations::obtain_avg_lum(const std::string& filename) {
 try {
 	Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(filename);
 	image->readMetadata();
@@ -92,6 +114,7 @@ try {
 	Exiv2::ExifData::const_iterator iiso  = exifData.findKey(Exiv2::ExifKey("Exif.Photo.ISOSpeedRatings"));
 	Exiv2::ExifData::const_iterator ifnum = exifData.findKey(Exiv2::ExifKey("Exif.Photo.FNumber"));
 	Exiv2::ExifData::const_iterator ifnum2 = exifData.findKey(Exiv2::ExifKey("Exif.Photo.ApertureValue"));
+	// default not valid values
 	float expo=-1; float iso=-1; float fnum=-1;
 
 	if (iexpo != exifData.end()) {
@@ -113,18 +136,21 @@ try {
 	} else if (ifnum2 != exifData.end()) {
 		fnum=static_cast<float>(std::exp(std::log(2.0) * ifnum2->toFloat() / 2));
 	}
+	// some cameras/lens DO print the fnum but with value 0, and this is not allowed for ev computation purposes.
 	if (fnum==0)
 		return -1;
 
+	//if iso is found use that value, otherwise assume a value of iso=100. (again, some cameras do not print iso in exif).
 	if (iiso == exifData.end()) {
 		iso=100.0;
 	} else {
 		iso=iiso->toFloat();
 	}
 
+	//At this point the three variables have to be != -1
 	if (expo!=-1 && iso!=-1 && fnum!=-1) {
 // 		std::cerr << "expo=" << expo << " fnum=" << fnum << " iso=" << iso << " |returned=" << (expo * iso) / (fnum*fnum*12.07488f) << std::endl;
-		return ( (expo * iso) / (fnum*fnum*12.07488f) ); //this is PFM :)
+		return ( (expo * iso) / (fnum*fnum*12.07488f) );
 	} else {
 		return -1;
 	}
