@@ -43,12 +43,13 @@ enum TResponse
 enum TModel
 { ROBERTSON, DEBEVEC };
 
+//TODO locate where variables of this type get destroied and free() LoadCurveFromFilename
 struct config_triple {
 	TWeight weights;
 	TResponse response_curve;
 	TModel model;
-	QString LoadCurveFromFilename;
-	QString SaveCurveToFilename;
+	const char* LoadCurveFromFilename;
+	const char* SaveCurveToFilename;
 };
 
 /**
