@@ -1,8 +1,8 @@
 /**
  * This file is a part of Qtpfsgui package.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
  */
@@ -24,7 +24,9 @@
 #include <QFileDialog>
 #include <QDir>
 #include <QFileInfo>
+#include <QMdiSubWindow>
 #include <QMessageBox>
+#include <QProgressDialog>
 #include <QWhatsThis>
 #include <QSignalMapper>
 #include <QTextStream>
@@ -36,6 +38,7 @@
 #include "../TransplantExif/transplant.h"
 #include "../Batch/batch_dialog.h"
 #include "../Threads/loadHdrThread.h"
+#include "DnDOption.h"
 #include "../Common/config.h"
 #include "hdrviewer.h"
 #include "../Common/global.h"
@@ -46,6 +49,8 @@ void writeEXRfile  (pfs::Frame* inputpfsframe, const char* outfilename);
 
 MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL) {
 	setupUi(this);
+	setAcceptDrops(true);
+
 	//main toolbar setup
 	QActionGroup *toolBarOptsGroup = new QActionGroup(this);
 	toolBarOptsGroup->addAction(actionText_Under_Icons);
@@ -54,16 +59,18 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL) {
 	toolBarOptsGroup->addAction(actionText_Only);
 	menuToolbars->addAction(toolBar->toggleViewAction());
 
-	workspace = new QWorkspace(this);
-	workspace->setScrollBarsEnabled( TRUE );
-	setCentralWidget(workspace);
+	mdiArea = new QMdiArea(this);
+	mdiArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+	mdiArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+	mdiArea->setBackground(QBrush(QColor::fromRgb(192, 192, 192)) );
+	setCentralWidget(mdiArea);
 
 	qtpfsgui_options=QtpfsguiOptions::getInstance();
 	load_options();
 
 	setWindowTitle("Qtpfsgui "QTPFSGUIVERSION);
 
-	connect(workspace,SIGNAL(windowActivated(QWidget*)),this,SLOT(updateActions(QWidget*)));
+	connect(mdiArea,SIGNAL(subWindowActivated(QMdiSubWindow*)),this,SLOT(updateActions(QMdiSubWindow*)));
 	connect(fileNewAction, SIGNAL(triggered()), this, SLOT(fileNewViaWizard()));
 	connect(fileOpenAction, SIGNAL(triggered()), this, SLOT(fileOpen()));
 	connect(fileSaveAsAction, SIGNAL(triggered()), this, SLOT(fileSaveAs()));
@@ -89,8 +96,8 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL) {
 	connect(actionAbout_Qtpfsgui,SIGNAL(triggered()),this,SLOT(aboutQtpfsgui()));
 	connect(OptionsAction,SIGNAL(triggered()),this,SLOT(preferences_called()));
 	connect(Transplant_Exif_Data_action,SIGNAL(triggered()),this,SLOT(transplant_called()));
-	connect(actionTile,SIGNAL(triggered()),workspace,SLOT(tile()));
-	connect(actionCascade,SIGNAL(triggered()),workspace,SLOT(cascade()));
+	connect(actionTile,SIGNAL(triggered()),mdiArea,SLOT(tileSubWindows()));
+	connect(actionCascade,SIGNAL(triggered()),mdiArea,SLOT(cascadeSubWindows()));
 	connect(fileExitAction, SIGNAL(triggered()), this, SLOT(fileExit()));
 	connect(menuWindows, SIGNAL(aboutToShow()), this, SLOT(updateWindowMenu()));
 	connect(actionSave_Hdr_Preview, SIGNAL(triggered()), this, SLOT(saveHdrPreview()));
@@ -102,7 +109,7 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL) {
 	connect(actionText_Only,SIGNAL(triggered()),this,SLOT(Text_Only()));
 
 	windowMapper = new QSignalMapper(this);
-	connect(windowMapper,SIGNAL(mapped(QWidget*)),workspace,SLOT(setActiveWindow(QWidget*)));
+	connect(windowMapper,SIGNAL(mapped(QWidget*)),this,SLOT(setActiveSubWindow(QWidget*)));
 
 	//recent files
 	for (int i = 0; i < MaxRecentFiles; ++i) {
@@ -116,19 +123,19 @@ MainGui::MainGui(QWidget *p) : QMainWindow(p), currenthdr(NULL) {
 	updateRecentFileActions();
 
 	//this->showMaximized();
-	
+
 	testTempDir(qtpfsgui_options->tempfilespath);
 	statusBar()->showMessage(tr("Ready.... Now open an Hdr or create one!"),17000);
 }
 
-void MainGui::fileNewViaWizard() {
+void MainGui::fileNewViaWizard(QStringList files) {
 	HdrWizardForm *wizard;
 	if (testTempDir(qtpfsgui_options->tempfilespath)) {
-		wizard=new HdrWizardForm (this);
+		wizard=new HdrWizardForm (this, files);
 		if (wizard->exec() == QDialog::Accepted) {
 			HdrViewer *newmdi=new HdrViewer( this, qtpfsgui_options->negcolor, qtpfsgui_options->naninfcolor, true); //true means needs saving
 			newmdi->updateHDR(wizard->getPfsFrameHDR());
-			workspace->addWindow(newmdi);
+			mdiArea->addSubWindow(newmdi);
 			newmdi->setWindowTitle(wizard->getCaptionTEXT());
 			newmdi->show();
 		}
@@ -158,7 +165,7 @@ void MainGui::addHdrViewer(pfs::Frame* hdr_pfs_frame, QString fname) {
 	newhdr->updateHDR(hdr_pfs_frame);
 	newhdr->filename=fname;
 	newhdr->setWindowTitle(fname);
-	workspace->addWindow(newhdr);
+	mdiArea->addSubWindow(newhdr);
 	newhdr->show();
 	setCurrentFile(fname);
 }
@@ -173,59 +180,63 @@ void MainGui::fileSaveAs()
 {
 	if (currenthdr==NULL)
 		return;
-	QStringList filetypes;
-	filetypes += tr("All Hdr formats (*.exr *.hdr *.pic *.tiff *.tif *.pfs)");
-	filetypes += "OpenEXR (*.exr)";
-	filetypes += "Radiance RGBE (*.hdr *.pic)";
-	filetypes += "HDR TIFF (*.tiff *.tif)";
+
+	QString filetypes = tr("All Hdr formats ");
+	filetypes += "(*.exr *.hdr *.pic *.tiff *.tif *.pfs);;" ;
+	filetypes += "OpenEXR (*.exr);;" ;
+	filetypes += "Radiance RGBE (*.hdr *.pic);;";
+	filetypes += "HDR TIFF (*.tiff *.tif);;";
 	filetypes += "PFS Stream (*.pfs)";
 
-	QFileDialog *fd = new QFileDialog(this);
-	fd->setWindowTitle(tr("Save the HDR..."));
-	fd->setDirectory(RecentDirHDRSetting);
-	fd->setFileMode(QFileDialog::AnyFile);
-	fd->setFilters(filetypes);
-	fd->setAcceptMode(QFileDialog::AcceptSave);
-	fd->setConfirmOverwrite(true);
-	fd->setDefaultSuffix("exr");
-	if (fd->exec()) {
-		QString fname=(fd->selectedFiles()).at(0);
-		if(!fname.isEmpty()) {
-			QFileInfo qfi(fname);
-			const char* encodedName=QFile::encodeName(qfi.filePath()).constData();
-			// if the new dir, the one just chosen by the user, is different from the one stored in the settings, update the settings.
-			if (RecentDirHDRSetting != qfi.path() )
-				// update internal field variable
-				updateRecentDirHDRSetting(qfi.path());
+	QString fname = QFileDialog::getSaveFileName(
+			this,
+			tr("Save the HDR..."),
+			RecentDirHDRSetting,
+			filetypes
+	);
 
-			if (qfi.suffix().toUpper()=="EXR") {
-				writeEXRfile  (currenthdr->getHDRPfsFrame(),encodedName);
-			} else if (qfi.suffix().toUpper()=="HDR") {
-				writeRGBEfile (currenthdr->getHDRPfsFrame(), encodedName);
-			} else if (qfi.suffix().toUpper().startsWith("TIF")) {
-				TiffWriter tiffwriter(encodedName, currenthdr->getHDRPfsFrame());
-				if (qtpfsgui_options->saveLogLuvTiff)
-					tiffwriter.writeLogLuvTiff();
-				else
-					tiffwriter.writeFloatTiff();
-			} else if (qfi.suffix().toUpper()=="PFS") {
-				pfs::DOMIO pfsio;
-				(currenthdr->getHDRPfsFrame())->convertRGBChannelsToXYZ();
-				pfsio.writeFrame(currenthdr->getHDRPfsFrame(),encodedName);
-				(currenthdr->getHDRPfsFrame())->convertXYZChannelsToRGB();
-			} else {
-				QMessageBox::warning(this,tr("Aborting..."), tr("Qtpfsgui supports only the following formats: <br>Radiance RGBE (hdr), PFS, tiff-hdr and OpenEXR."),
-				QMessageBox::Ok,QMessageBox::NoButton);
-				delete fd;
-				return;
-			}
-			setCurrentFile(fname);
-			currenthdr->NeedsSaving=false;
-			currenthdr->filename=fname;
-			currenthdr->setWindowTitle(fname);
+	if(!fname.isEmpty()) {
+		QFileInfo qfi(fname);
+		QString absoluteFileName=qfi.absoluteFilePath();
+		char* encodedName=strdup(QFile::encodeName(absoluteFileName).constData());
+		// if the new dir, the one just chosen by the user, is different from the one stored in the settings, update the settings.
+		if (RecentDirHDRSetting != qfi.path() )
+			// update internal field variable
+			updateRecentDirHDRSetting(qfi.path());
+
+		if (qfi.suffix().toUpper()=="EXR") {
+			writeEXRfile  (currenthdr->getHDRPfsFrame(),encodedName);
+		} else if (qfi.suffix().toUpper()=="HDR") {
+			writeRGBEfile (currenthdr->getHDRPfsFrame(), encodedName);
+		} else if (qfi.suffix().toUpper().startsWith("TIF")) {
+			TiffWriter tiffwriter(encodedName, currenthdr->getHDRPfsFrame());
+			if (qtpfsgui_options->saveLogLuvTiff)
+				tiffwriter.writeLogLuvTiff();
+			else
+				tiffwriter.writeFloatTiff();
+		} else if (qfi.suffix().toUpper()=="PFS") {
+			pfs::DOMIO pfsio;
+			(currenthdr->getHDRPfsFrame())->convertRGBChannelsToXYZ();
+			pfsio.writeFrame(currenthdr->getHDRPfsFrame(),encodedName);
+			(currenthdr->getHDRPfsFrame())->convertXYZChannelsToRGB();
+		} else {
+			// TODO: [QT 4.5] This is not needed for windows (bug will be fixed in QT 4.5..?)
+
+			// Default as EXR
+			free(encodedName);
+			absoluteFileName = absoluteFileName + ".exr";
+			encodedName = strdup(QFile::encodeName(absoluteFileName).constData());
+			writeEXRfile  (currenthdr->getHDRPfsFrame(),encodedName);
+//			QMessageBox::warning(this,tr("Aborting..."), tr("Qtpfsgui supports only the following formats: <br>Radiance RGBE (hdr), PFS, tiff-hdr and OpenEXR."),
+//			QMessageBox::Ok,QMessageBox::NoButton);
+//			return;
 		}
-	} //if (fd->exec())
-	delete fd;
+		free(encodedName);
+		setCurrentFile(absoluteFileName);
+		currenthdr->NeedsSaving=false;
+		currenthdr->filename=absoluteFileName;
+		currenthdr->setWindowTitle(absoluteFileName);
+	}
 }
 
 void MainGui::saveHdrPreview() {
@@ -234,7 +245,7 @@ void MainGui::saveHdrPreview() {
 	currenthdr->saveHdrPreview();
 }
 
-void MainGui::updateActions( QWidget * w ) {
+void MainGui::updateActions( QMdiSubWindow * w ) {
 	action_Projective_Transformation->setEnabled(w!=NULL);
 	actionSave_Hdr_Preview->setEnabled(w!=NULL);
 	TonemapAction->setEnabled(w!=NULL);
@@ -250,7 +261,7 @@ void MainGui::updateActions( QWidget * w ) {
 	Increase_exposure->setEnabled(w!=NULL);
 	actionResizeHDR->setEnabled(w!=NULL);
 	if (w!=NULL) {
-		currenthdr=(HdrViewer*)(workspace->activeWindow());
+		currenthdr=(HdrViewer*)(mdiArea->activeSubWindow()->widget());
 		if (currenthdr->getFittingWin()) {
 			normalSizeAct->setEnabled(false);
 			zoomInAct->setEnabled(false);
@@ -271,6 +282,13 @@ void MainGui::updateActions( QWidget * w ) {
 	}
 }
 
+void MainGui::setActiveSubWindow(QWidget* w) {
+	QList<QMdiSubWindow*> allhdrs=mdiArea->subWindowList();
+	foreach(QMdiSubWindow *p,allhdrs)
+		if (p->widget() == w)
+			mdiArea->setActiveSubWindow(p);
+}
+
 void MainGui::tonemap_requested() {
 	if(currenthdr==NULL)
 		return;
@@ -427,10 +445,10 @@ void MainGui::setCurrentFile(const QString &fileName) {
 
 void MainGui::updateRecentFileActions() {
 	QStringList files = settings.value(KEY_RECENT_FILES).toStringList();
-	
+
 	int numRecentFiles = qMin(files.size(), (int)MaxRecentFiles);
 	separatorRecentFiles->setVisible(numRecentFiles > 0);
-	
+
 	for (int i = 0; i < numRecentFiles; ++i) {
 		QString text = QString("&%1 %2").arg(i + 1).arg(QFileInfo(files[i]).fileName());
 		recentFileActs[i]->setText(text);
@@ -472,9 +490,9 @@ void MainGui::preferences_called() {
 	PreferenceDialog *opts=new PreferenceDialog(this);
 	opts->setAttribute(Qt::WA_DeleteOnClose);
 	if (opts->exec() == QDialog::Accepted && (negcol!=qtpfsgui_options->negcolor || naninfcol!=qtpfsgui_options->naninfcolor) ) {
-		QWidgetList allhdrs=workspace->windowList();
-		foreach(QWidget *p,allhdrs) {
-			((HdrViewer*)p)->update_colors(qtpfsgui_options->negcolor,qtpfsgui_options->naninfcolor);
+		QList<QMdiSubWindow*> allhdrs=mdiArea->subWindowList();
+		foreach(QMdiSubWindow *p,allhdrs) {
+			((HdrViewer*)p->widget())->update_colors(qtpfsgui_options->negcolor,qtpfsgui_options->naninfcolor);
 		}
 	}
 }
@@ -512,6 +530,33 @@ void MainGui::load_options() {
 	}
 }
 
+void MainGui::dragEnterEvent(QDragEnterEvent *event) {
+	event->acceptProposedAction();
+}
+
+void MainGui::dropEvent(QDropEvent *event) {
+
+	if (event->mimeData()->hasUrls()) {
+		QStringList files = convertUrlListToFilenameList(event->mimeData()->urls());
+		if (files.size() > 0) {
+			DnDOptionDialog dndOption(this, files);
+			dndOption.exec();
+
+			switch (dndOption.result) {
+			case 1: // create new using LDRS
+				fileNewViaWizard(files);
+				break;
+			case 2: // openHDRs
+				foreach (QString file, files) {
+					setupLoadThread(file);
+				}
+				break;
+			}
+		}
+	}
+	event->acceptProposedAction();
+}
+
 MainGui::~MainGui() {
 	for (int i = 0; i < MaxRecentFiles; ++i) {
 		delete recentFileActs[i];
@@ -519,20 +564,15 @@ MainGui::~MainGui() {
 }
 
 void MainGui::fileExit() {
-	QWidgetList allhdrs=workspace->windowList();
+	QList<QMdiSubWindow*> allhdrs=mdiArea->subWindowList();
 	bool closeok=true;
-	foreach(QWidget *p,allhdrs) {
-		if (((HdrViewer*)p)->NeedsSaving)
+	foreach(QMdiSubWindow *p,allhdrs) {
+		if (((HdrViewer*)p->widget())->NeedsSaving)
 			closeok=false;
 	}
 	if (closeok || (QMessageBox::warning(this,tr("Unsaved changes..."),tr("There is at least one Hdr with unsaved changes.<br>Do you still want to quit?"),
-#if QT_VERSION <= 0x040200
-			QMessageBox::Yes | QMessageBox::Default, QMessageBox::No,QMessageBox::NoButton)
-		== QMessageBox::Yes))
-#else
 			QMessageBox::Yes | QMessageBox::No, QMessageBox::No)
 		== QMessageBox::Yes))
-#endif
 		emit close();
 }
 
@@ -561,11 +601,9 @@ void MainGui::aboutQtpfsgui() {
 	about->setAttribute(Qt::WA_DeleteOnClose);
 	Ui::AboutQtpfsgui ui;
 	ui.setupUi(about);
-#if QT_VERSION >= 0x040200
 	ui.authorsBox->setOpenExternalLinks(true);
 	ui.thanksToBox->setOpenExternalLinks(true);
 	ui.GPLbox->setTextInteractionFlags(Qt::TextSelectableByMouse);
-#endif
 	ui.label_version->setText(ui.label_version->text().append(QString(QTPFSGUIVERSION)));
 
 	bool license_file_not_found=true;
@@ -590,10 +628,8 @@ void MainGui::aboutQtpfsgui() {
 		}
 	}
 	if (license_file_not_found) {
-#if QT_VERSION >= 0x040200
 		ui.GPLbox->setOpenExternalLinks(true);
 		ui.GPLbox->setTextInteractionFlags(Qt::TextBrowserInteraction);
-#endif
 		ui.GPLbox->setHtml(tr("%1 License document not found, you can find it online: %2here%3","%2 and %3 are html tags").arg("<html>").arg("<a href=\"http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt\">").arg("</a></html>"));
 	}
 	about->show();
@@ -601,10 +637,10 @@ void MainGui::aboutQtpfsgui() {
 
 void MainGui::updateWindowMenu() {
 	menuWindows->clear();
-	QList<QWidget *> windows = workspace->windowList();
+	QList<QMdiSubWindow *> windows = mdiArea->subWindowList();
 	for (int i = 0; i < windows.size(); ++i) {
-		HdrViewer *child = qobject_cast<HdrViewer *>(windows.at(i));
-		QString text=QString((i < 9)?"&":"") + QString("%1 %2").arg(i + 1).arg(QFileInfo((child->filename.isEmpty())? "Untitled":child->filename).fileName());
+		HdrViewer *child = qobject_cast<HdrViewer *>(windows.at(i)->widget());
+		QString text=QString((i < 9)?"&":"") + QString("%1 %2").arg(i + 1).arg(QFileInfo((child->filename.isEmpty())? tr("Untitled"):child->filename).fileName());
 		QAction *action  = menuWindows->addAction(text);
 		action->setCheckable(true);
 		action->setChecked(child==currenthdr);
