@@ -1,8 +1,8 @@
 /**
  * This file is a part of Qtpfsgui package.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
  */
@@ -25,7 +25,7 @@
 #define MAINGUI_IMPL_H
 
 #include <QMainWindow>
-#include <QWorkspace>
+#include <QMdiArea>
 #include <QStringList>
 #include "../HdrWizard/newHdrWizard.h"
 #include "../../generated_uic/ui_maingui.h"
@@ -45,7 +45,7 @@ public:
 	HdrViewer* currenthdr;
 public  slots:
 private slots:
-	void fileNewViaWizard();
+	void fileNewViaWizard(QStringList files = QStringList());
 	void fileOpen();//for File->Open, it then calls loadFile()
 	void fileSaveAs();
 	void saveHdrPreview();
@@ -84,7 +84,11 @@ private slots:
 	void load_failed(QString);
 	void aboutQtpfsgui();
 
-	void updateActions( QWidget * w );
+	void updateActions( QMdiSubWindow * w );
+	void setActiveSubWindow(QWidget* w);
+protected:
+	virtual void dragEnterEvent(QDragEnterEvent *);
+	virtual void dropEvent(QDropEvent *);
 
 private:
 	void dispatchrotate( bool clockwise);
@@ -92,7 +96,7 @@ private:
 	void load_options();
 	void setupLoadThread(QString);
 	bool testTempDir(QString);
-	QWorkspace* workspace;
+	QMdiArea* mdiArea;
 	QSignalMapper *windowMapper;
 	enum { MaxRecentFiles = 5 };
 	QAction *recentFileActs[MaxRecentFiles];
