@@ -10,9 +10,9 @@
  * Some code from Numerical Recipes in C
  *
  * This file is a part of Qtpfsgui package, based on pfstmo.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2003,2004 Grzegorz Krawczyk
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -26,9 +26,9 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
- * 
- * $Id: pde.cpp,v 1.7 2005/11/29 18:36:55 aefremov Exp $
+ * ----------------------------------------------------------------------
+ *
+ * $Id: pde.cpp,v 1.3 2008/09/04 12:46:49 julians37 Exp $
  */
 
 #include <iostream>
@@ -37,7 +37,6 @@
 #include <stdlib.h>
 #include <math.h>
 
-#include "../../Libpfs/array2d.h"
 #include "pde.h"
 
 using namespace std;
@@ -71,7 +70,7 @@ inline float min( float a, float b )
 
 //!!: for debugging purposes
 // #define PFSEOL "\x0a"
-// static void dumpPFS( const char *fileName, const pfs::Array2D *data, const char *channelName )
+// static void dumpPFS( const char *fileName, const pfstmo::Array2D *data, const char *channelName )
 // {
 //   FILE *fh = fopen( fileName, "wb" );
 //   assert( fh != NULL );
@@ -86,7 +85,7 @@ inline float min( float a, float b )
 //     for( int x = 0; x < width; x++ ) {
 //       fwrite( &((*data)(x,y)), sizeof( float ), 1, fh );
 //     }
-  
+
 //   fclose( fh );
 // }
 
@@ -94,7 +93,7 @@ inline float min( float a, float b )
 // Full Multigrid Algorithm for solving partial differential equations
 //////////////////////////////////////////////////////////////////////
 
-void restrict( const pfs::Array2D *in, pfs::Array2D *out )
+void restrict( const pfstmo::Array2D *in, pfstmo::Array2D *out )
 {
   const float inRows = in->getRows();
   const float inCols = in->getCols();
@@ -106,10 +105,10 @@ void restrict( const pfs::Array2D *in, pfs::Array2D *out )
   const float dy = (float)in->getRows() / (float)out->getRows();
 
   const float filterSize = 0.5f;
-  
+
   float sx, sy;
   int x, y;
-  
+
   for( y = 0, sy = dy/2-0.5f; y < outRows; y++, sy += dy )
     for( x = 0, sx = dx/2-0.5f; x < outCols; x++, sx += dx ) {
 
@@ -119,16 +118,16 @@ void restrict( const pfs::Array2D *in, pfs::Array2D *out )
         for( float iy = max( 0, ceilf( sy-dx*filterSize ) ); iy <= min( floorf( sy+dx*filterSize), inRows-1 ); iy++ ) {
           pixVal += (*in)( (int)ix, (int)iy );
           w += 1;
-        }     
-      (*out)(x,y) = pixVal/w;      
+        }
+      (*out)(x,y) = pixVal/w;
     }
 }
 
 // from_level>to_level, from_size>to_size
-// void restrict( pfs::Array2D *F, pfs::Array2D *T )
+// void restrict( pfstmo::Array2D *F, pfstmo::Array2D *T )
 // {
 // //   DEBUG_STR << "restrict" << endl;
-  
+
 //   int sxt = T->getCols();
 //   int syt = T->getRows();
 //   int sxf = F->getCols();
@@ -157,13 +156,13 @@ void restrict( const pfs::Array2D *in, pfs::Array2D *out )
 // }
 
 
-void prolongate( const pfs::Array2D *in, pfs::Array2D *out )
+void prolongate( const pfstmo::Array2D *in, pfstmo::Array2D *out )
 {
   float dx = (float)in->getCols() / (float)out->getCols();
   float dy = (float)in->getRows() / (float)out->getRows();
 
   float pad;
-  
+
   /*float filterSamplingX = */max( modff( dx, &pad ), 0.01f );
   /*float filterSamplingY = */max( modff( dy, &pad ), 0.01f );
 
@@ -182,26 +181,26 @@ void prolongate( const pfs::Array2D *in, pfs::Array2D *out )
 
       float pixVal = 0;
       float weight = 0;
-      
+
       for( float ix = max( 0, ceilf( sx-filterSize ) ); ix <= min( floorf(sx+filterSize), inCols-1 ); ix++ )
         for( float iy = max( 0, ceilf( sy-filterSize ) ); iy <= min( floorf( sy+filterSize), inRows-1 ); iy++ ) {
           float fx = fabsf( sx - ix );
           float fy = fabsf( sy - iy );
 
           const float fval = (1-fx)*(1-fy);
-          
+
           pixVal += (*in)( (int)ix, (int)iy ) * fval;
           weight += fval;
         }
-      
+
       assert( weight != 0 );
       (*out)(x,y) = pixVal / weight;
 
-    } 
+    }
 }
 
 // to_level<from_level, from_size<to_size
-void prolongate_old( pfs::Array2D *F, pfs::Array2D *T )
+void prolongate_old( pfstmo::Array2D *F, pfstmo::Array2D *T )
 {
 //   DEBUG_STR << "prolongate" << endl;
 
@@ -215,7 +214,7 @@ void prolongate_old( pfs::Array2D *F, pfs::Array2D *T )
   for( x=0 ; x<sxf ; x++ )
     for( y=0 ; y<syf ; y++ )
     {
-      int x2 = x*2;            
+      int x2 = x*2;
       int y2 = y*2;
       if(x2<sxt && y2<syt)
         (*T)(x2,y2) = (*F)(x,y);
@@ -231,7 +230,7 @@ void prolongate_old( pfs::Array2D *F, pfs::Array2D *T )
   }
   if( syt & 1 ) {
     for( x=0 ; x<sxf ; x++ ) {
-      int x2 = x*2;            
+      int x2 = x*2;
       if(x2<sxt)
         (*T)(x2,syt-1) = (*F)(x,syf-1);
     }
@@ -262,7 +261,7 @@ void prolongate_old( pfs::Array2D *F, pfs::Array2D *T )
     }
 }
 
-void exact_sollution( pfs::Array2D *F, pfs::Array2D *U )
+void exact_sollution( pfstmo::Array2D *F, pfstmo::Array2D *U )
 {
 //   DEBUG_STR << "exact sollution" << endl;
 
@@ -274,11 +273,11 @@ void exact_sollution( pfs::Array2D *F, pfs::Array2D *U )
 //   float h2 = h*h;
 
     setArray( U, 0.0f); return;   /* also works well?? */
-  
+
 //   if( sx==3 && sy==3 )
 //   {
 //     (*U)(1,1) = -h2* (*F)(1,1) / 4.0f;
-    
+
 //     // boundary points
 //     for( x=0 ; x<sx ; x++ )
 //       (*U)(x,0) = (*U)(x,sy-1) = 0.0f;
@@ -288,7 +287,7 @@ void exact_sollution( pfs::Array2D *F, pfs::Array2D *U )
 //   else
 //   {
 //     setArray( U, 0.0f); return;   /* also works well?? */
-  
+
 //     // TODO: this produces incorrect results
 // //     solve_pde_sor(F,U);
 // //     for( y=0 ; y<sy ; y++ )
@@ -305,29 +304,29 @@ inline int idx( int r, int c )
 }
 
 // smooth u using f at level
-void smooth( pfs::Array2DImpl *U, pfs::Array2DImpl *F )
+void smooth( pfstmo::Array2D *U, pfstmo::Array2D *F )
 {
 //   DEBUG_STR << "smooth" << endl;
-  
+
   rows = U->getRows();
   cols = U->getCols();
-  
+
   const int n = rows*cols;
 
   int iter;
   float err;
-        
+
   linbcg( n, F->getRawData()-1, U->getRawData()-1, 1, 0.001, BCG_STEPS, &iter, &err);
 
 //   fprintf( stderr, "." );
 
   // Gauss relaxation is too slow
-  
+
 //   int sx = F->getCols();
 //   int sy = F->getRows();
 //   int x,y,i;
 //   int shx;	shift x
-  
+
 //   float h = 1.0f/sqrtf(sx*sy*1.0f);
 //   float h2 = h*h;
 
@@ -346,15 +345,15 @@ void smooth( pfs::Array2DImpl *U, pfs::Array2DImpl *F )
 //         n = (y == 0 ? 0 : y-1);
 //         s = (y+1 == sy ? y : y+1);
 //         e = (x+1 == sx ? x : x+1);
-        
+
 // 	(*U)(x,y) = .25 * ( (*U)(e,y) + (*U)(w,y) + (*U)(x,s) + (*U)(x,n)
-//           - h2 * (*F)(x,y) );        
+//           - h2 * (*F)(x,y) );
 //       }
 //     }
 //   }
 }
 
-void calculate_defect( pfs::Array2D *D, pfs::Array2D *U, pfs::Array2D *F )
+void calculate_defect( pfstmo::Array2D *D, pfstmo::Array2D *U, pfstmo::Array2D *F )
 {
 //   DEBUG_STR << "calculate defect" << endl;
 
@@ -373,14 +372,14 @@ void calculate_defect( pfs::Array2D *D, pfs::Array2D *U, pfs::Array2D *F )
         n = (y == 0 ? 0 : y-1);
         s = (y+1 == sy ? y : y+1);
         e = (x+1 == sx ? x : x+1);
-      
+
         (*D)(x,y) = (*F)(x,y) -( (*U)(e,y) + (*U)(w,y) + (*U)(x,n) + (*U)(x,s)
           - 4.0 * (*U)(x,y) );
     }
-  
+
 }
 
-void add_correction( pfs::Array2D *U, pfs::Array2D *C )
+void add_correction( pfstmo::Array2D *U, pfstmo::Array2D *C )
 {
 //   DEBUG_STR << "add_correction" << endl;
 
@@ -392,11 +391,11 @@ void add_correction( pfs::Array2D *U, pfs::Array2D *C )
 }
 
 
-void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
+void solve_pde_multigrid( pfstmo::Array2D *F, pfstmo::Array2D *U )
 {
   int xmax = F->getCols();
   int ymax = F->getRows();
-  
+
   int i;	// index for simple loops
   int k;	// index for iterating through levels
   int k2;	// index for iterating through levels in V-cycles
@@ -414,17 +413,17 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
   }
 
   // given function f restricted on levels
-  pfs::Array2D** RHS = new pfs::Array2D*[levels+1];
+  pfstmo::Array2D** RHS = new pfstmo::Array2D*[levels+1];
 
   // approximate initial sollutions on levels
-  pfs::Array2DImpl** IU = new pfs::Array2DImpl*[levels+1];
+  pfstmo::Array2D** IU = new pfstmo::Array2D*[levels+1];
   // target functions in cycles (approximate sollution error (uh - ~uh) )
-  pfs::Array2DImpl** VF = new pfs::Array2DImpl*[levels+1];
+  pfstmo::Array2D** VF = new pfstmo::Array2D*[levels+1];
 
-  VF[0] = new pfs::Array2DImpl(xmax,ymax);
+  VF[0] = new pfstmo::Array2D(xmax,ymax);
   RHS[0] = F;
-  IU[0] = new pfs::Array2DImpl(xmax,ymax);
-  pfs::copyArray( U, IU[0] );
+  IU[0] = new pfstmo::Array2D(xmax,ymax);
+  pfstmo::copyArray( U, IU[0] );
 
   int sx=xmax;
   int sy=ymax;
@@ -434,10 +433,10 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
     // calculate size of next level
     sx=sx/2+MODYF;
     sy=sy/2+MODYF;
-    
-    RHS[k+1] = new pfs::Array2DImpl(sx,sy);
-    IU[k+1] = new pfs::Array2DImpl(sx,sy);
-    VF[k+1] = new pfs::Array2DImpl(sx,sy);
+
+    RHS[k+1] = new pfstmo::Array2D(sx,sy);
+    IU[k+1] = new pfstmo::Array2D(sx,sy);
+    VF[k+1] = new pfstmo::Array2D(sx,sy);
 
     // restrict from level k to level k+1 (coarser-grid)
     restrict( RHS[k], RHS[k+1] );
@@ -472,13 +471,13 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
           setArray( IU[k2], 0.0f );
 
 //        fprintf( stderr, "Level: %d --------\n", k2 );
-        
+
 	for( i=0 ; i<SMOOTH_IT ; i++ )
           smooth( IU[k2], VF[k2] );
 
         // 8. calculate defect at level
         //    d[k2] = Lh * ~u[k2] - f[k2]
-        pfs::Array2D* D = new pfs::Array2DImpl(IU[k2]->getCols(), IU[k2]->getRows());
+		pfstmo::Array2D* D = new pfstmo::Array2D(IU[k2]->getCols(), IU[k2]->getRows());
 	calculate_defect( D, IU[k2], VF[k2] );
 
         // 9. restrict deffect as target function for next coarser-grid
@@ -497,7 +496,7 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
       {
         // 12. interpolate correction from last coarser-grid to finer-grid
         //     iu[k2+1] -> cor
-        pfs::Array2D* C = new pfs::Array2DImpl(IU[k2]->getCols(), IU[k2]->getRows());
+	    pfstmo::Array2D* C = new pfstmo::Array2D(IU[k2]->getCols(), IU[k2]->getRows());
 	prolongate( IU[k2+1], C );
 
         // 13. add interpolated correction to initial sollution at level k2
@@ -505,7 +504,7 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
 	delete C;
 
 //        fprintf( stderr, "Level: %d --------\n", k2 );
-        
+
         // 14. post-smoothing of current sollution using target function
 	for( i=0 ; i<SMOOTH_IT ; i++ )
           smooth( IU[k2], VF[k2] );
@@ -526,10 +525,10 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
 //     dumpPFS( name, RHS[k], "Y" );
 //     sprintf( name, "v_%d.pfs", k );
 //     dumpPFS( name, VF[k], "Y" );
-//   }  
+//   }
+
+  pfstmo::copyArray( IU[0], U );
 
-  pfs::copyArray( IU[0], U );
-  
   delete VF[0];
   delete IU[0];
 
@@ -539,9 +538,9 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
     delete VF[k];
   }
 
-  delete RHS;
-  delete IU;
-  delete VF;
+  delete[] RHS;
+  delete[] IU;
+  delete[] VF;
 
 //   DEBUG_STR << "FMG: solved\n";
 }
@@ -553,13 +552,13 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
 // SOR - Succesive Overrelaxation Algorithm
 //////////////////////////////////////////////////////////////////////
 
-void solve_pde_sor( pfs::Array2D *F, pfs::Array2D *U, int maxits)
+void solve_pde_sor( pfstmo::Array2D *F, pfstmo::Array2D *U, int maxits)
 {
 //   DEBUG_STR << "sor" << endl;
 
   int xmax = F->getCols();
   int ymax = F->getRows();
-  
+
   float rjac = 1.0 - 6.28/((xmax>ymax) ? xmax : ymax);
   int	ipass, j, jsw, l, lsw, n;
   float anorm, anormf = 0.0, omega = 1.0, resid;
@@ -591,7 +590,7 @@ void solve_pde_sor( pfs::Array2D *F, pfs::Array2D *U, int maxits)
           if( jm1<0 ) jm1=jp1;
           if( lp1>=ymax ) lp1=lm1;
           if( lm1<0 ) lm1=lp1;
-          
+
 	  resid = (*U)(jp1,l) + (*U)(jm1,l) + (*U)(j,lp1) + (*U)(j,lm1)
             - 4.0* (*U)(j,l) - (*F)(j,l);
 	  anorm += fabsf(resid);
@@ -631,7 +630,7 @@ void atimes(unsigned int /*n*/, float x[], float res[], int /*itrnsp*/)
     for( int c = 1; c < cols-1; c++ ) {
       res[idx(r,c)] = x[idx(r-1,c)] + x[idx(r+1,c)] +
         x[idx(r,c-1)] + x[idx(r,c+1)] - 4*x[idx(r,c)];
-    }        
+    }
 
   for( int r = 1; r < rows-1; r++ ) {
     res[idx(r,0)] = x[idx(r-1,0)] + x[idx(r+1,0)] +
@@ -639,7 +638,7 @@ void atimes(unsigned int /*n*/, float x[], float res[], int /*itrnsp*/)
     res[idx(r,cols-1)] = x[idx(r-1,cols-1)] + x[idx(r+1,cols-1)] +
         x[idx(r,cols-2)] - 3*x[idx(r,cols-1)];
   }
-  
+
   for( int c = 1; c < cols-1; c++ ) {
     res[idx(0,c)] = x[idx(1,c)] +
         x[idx(0,c-1)] + x[idx(0,c+1)] - 3*x[idx(0,c)];
@@ -650,7 +649,7 @@ void atimes(unsigned int /*n*/, float x[], float res[], int /*itrnsp*/)
   res[idx(rows-1,0)] = x[idx(rows-2,0)] + x[idx(rows-1,1)] - 2*x[idx(rows-1,0)];
   res[idx(0,cols-1)] = x[idx(1,cols-1)] + x[idx(0,cols-2)] - 2*x[idx(0,cols-1)];
   res[idx(rows-1,cols-1)] = x[idx(rows-2,cols-1)] + x[idx(rows-1,cols-2)]
-    - 2*x[idx(rows-1,cols-1)];  
+    - 2*x[idx(rows-1,cols-1)];
 }
 
 float snrm(unsigned int n, float sx[], int itol)
@@ -676,7 +675,7 @@ float snrm(unsigned int n, float sx[], int itol)
  * from Numerical Recipes in C
  */
 void linbcg(unsigned int n, float b[], float x[], int itol, float tol,	int itmax, int *iter, float *err)
-{	
+{
 	unsigned int j;
 	float ak,akden,bk,bkden,bknum,bnrm,dxnrm,xnrm,zm1nrm,znrm;
 	float *p,*pp,*r,*rr,*z,*zz;
@@ -707,7 +706,7 @@ void linbcg(unsigned int n, float b[], float x[], int itol, float tol,	int itmax
 		asolve(n,r,z,0);
 		znrm=snrm(n,z,itol);
 	} else printf("illegal itol in linbcg");
-	asolve(n,r,z,0);        
+	asolve(n,r,z,0);
 
 	while (*iter <= itmax) {
 		++(*iter);
@@ -726,7 +725,7 @@ void linbcg(unsigned int n, float b[], float x[], int itol, float tol,	int itmax
 				p[j]=bk*p[j]+z[j];
 				pp[j]=bk*pp[j]+zz[j];
 			}
-		}                
+		}
 		bkden=bknum;
 		atimes(n,p,z,0);
 		for (akden=0.0,j=1;j<=n;j++) akden += z[j]*pp[j];
