@@ -1,8 +1,8 @@
 /**
  * This file is a part of Qtpfsgui package.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007,2008 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
  */
@@ -24,7 +24,7 @@
 #ifndef TONEMAPPINGDIALOG_IMPL_H
 #define TONEMAPPINGDIALOG_IMPL_H
 
-#include <QWorkspace>
+#include <QMdiArea>
 
 #include "../generated_uic/ui_tonemappingdialog.h"
 #include "../Common/global.h"
@@ -42,18 +42,19 @@ protected:
 signals:
 	void closing();
 private:
-	QWorkspace* workspace;
+	QMdiArea* mdiArea;
 	QString recentPathSaveLDR, prefixname;
 
 private slots:
 	void addMDIresult(const QImage&,tonemapping_options*);
 	void LevelsRequested(bool);
 	void levels_closed();
-	void updateActions(QWidget *);
+	void updateActions(QMdiSubWindow *);
 	void viewAllAsThumbnails();
 	void current_ldr_fit_to_win(bool);
-	void close_all();
-	void saveLDR();
+	void on_actionClose_All_triggered();
+	void on_actionSaveAll_triggered();
+	void on_actionSave_triggered();
 	void enterWhatsThis();
 };
 #endif
