@@ -1,8 +1,8 @@
 /**
  * This file is a part of Qtpfsgui package.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
  */
@@ -25,8 +25,10 @@
 #include <QFileDialog>
 #include <QTextStream>
 #include <QDir>
+#include <QInputDialog>
 #include <QStatusBar>
 #include <QProgressBar>
+#include <QLineEdit>
 #include <QKeyEvent>
 #include "tonemapping_widget.h"
 #include "../Common/config.h"
@@ -43,60 +45,45 @@ TMWidget::TMWidget(QWidget *parent, pfs::Frame* &_OriginalPfsFrame, QStatusBar *
 	// mantiuk06
 	contrastfactorGang = new Gang(contrastFactorSlider, contrastFactordsb,0.001,10,0.1);
 	saturationfactorGang = new Gang(saturationFactorSlider, saturationFactordsb,0,2,0.8);
+	detailfactorGang = new Gang(detailFactorSlider, detailFactordsb,1,99,1.0);
 
 	// ashikhmin02
 	contrastGang = 	new Gang(contrastSlider, contrastdsb,	0,	1,	0.5);
-	
+
 	// drago03
 	biasGang = 	new Gang(biasSlider, biasdsb,		0.5,	1,	0.85);
-	
+
 	// durand02
 	spatialGang = 	new Gang(spatialSlider, spatialdsb,	0,	60,	8);
 	rangeGang = 	new Gang(rangeSlider, rangedsb,		0.01,	10,	0.4);
 	baseGang = 	new Gang(baseSlider, basedsb,		0,	10,	5.0);
-	
+
 	// fattal02
 	alphaGang = 	new Gang(alphaSlider, alphadsb,		1e-3,	2,	1e-1, true);
 	betaGang = 	new Gang(betaSlider, betadsb,		0.6,	1.0,	0.8);
 	saturation2Gang = new Gang(saturation2Slider, saturation2dsb, 0,3,	1);
 	noiseGang =	new Gang(noiseSlider, noisedsb, 	0, 	1, 	0);
-	
+
 	// pattanaik00
 	multiplierGang = new Gang(multiplierSlider, multiplierdsb, 1e-3,50, 1, true);
 	coneGang = 	new Gang(coneSlider, conedsb,		0,	1,   0.5);
 	rodGang = 	new Gang(rodSlider, roddsb,		0,	1,   0.5);
-	
+
 	// reinhard02
 	keyGang = 	new Gang(keySlider, keydsb,		0,	1,   0.18);
 	phiGang = 	new Gang(phiSlider, phidsb,		0,	50,  1);
 	range2Gang = 	new Gang(range2Slider, range2dsb,	2, 	15,  8);
 	lowerGang = 	new Gang(lowerSlider, lowerdsb,		1,	100, 1);
 	upperGang = 	new Gang(upperSlider, upperdsb,		1,	100, 43);
-	
+
 	// reinhard05
 	brightnessGang =new Gang(brightnessSlider, brightnessdsb,	-35,	10, -10);
 	chromaticGang  =new Gang(chromaticAdaptSlider, chromaticAdaptdsb, -1.7,	1.3, 1);
 	lightGang      =new Gang(lightAdaptSlider, lightAdaptdsb,         -1,	1, 0);
-	
+
 	// pregamma
 	pregammagang  = new Gang(pregammaSlider,  pregammadsb,  0, 3, 1);
 
-	connect(ashikhmin02Default, SIGNAL(clicked()),this,SLOT(ashikhminReset()));
-	connect(drago03Default,     SIGNAL(clicked()),this,SLOT(dragoReset()));
-	connect(durand02Default,    SIGNAL(clicked()),this,SLOT(durandReset()));
-	connect(fattal02Default,    SIGNAL(clicked()),this,SLOT(fattalReset()));
-	connect(pattanaik00Default, SIGNAL(clicked()),this,SLOT(pattanaikReset()));
-	connect(reinhard02Default,  SIGNAL(clicked()),this,SLOT(reinhard02Reset()));
-	connect(reinhard05Default,  SIGNAL(clicked()),this,SLOT(reinhard05Reset()));
-	connect(MantiukDefault,     SIGNAL(clicked()),this,SLOT(mantiukReset()));
-	connect(pregammadefault,    SIGNAL(clicked()),this,SLOT(preGammaReset()));
-
-	connect(applyButton,       SIGNAL(clicked()), this, SLOT(apply_clicked()));
-	connect(loadsettingsbutton,SIGNAL(clicked()), this, SLOT(loadsettings()));
-	connect(savesettingsbutton,SIGNAL(clicked()), this, SLOT(savesettings()));
-	connect(button_fromTxt2Gui,SIGNAL(clicked()), this, SLOT(fromTxt2Gui()));
-	connect(addCustomSizeButton, SIGNAL(clicked()), this, SLOT(addCustomSize()));
-
 	RecentPathLoadSaveTmoSettings=settings.value(KEY_RECENT_PATH_LOAD_SAVE_TMO_SETTINGS,QDir::currentPath()).toString();
 
 	// get available sizes
@@ -114,9 +101,7 @@ TMWidget::TMWidget(QWidget *parent, pfs::Frame* &_OriginalPfsFrame, QStatusBar *
 	}
 	sizes.push_back(width);
 	HeightWidthRatio = ( (float)height )/( (float) width);
-	for(int i = 0; i < sizes.size(); i++) {
-		sizeComboBox->addItem( QString("%1x%2").arg(sizes[i]).arg( (int)(HeightWidthRatio*sizes[i]) ));
-	}
+	fillCustomSizeComboBox();
 
 	qRegisterMetaType<QImage>("QImage");
 
@@ -127,7 +112,7 @@ TMWidget::TMWidget(QWidget *parent, pfs::Frame* &_OriginalPfsFrame, QStatusBar *
 }
 
 TMWidget::~TMWidget() {
-delete contrastfactorGang; delete saturationfactorGang; delete contrastGang; delete biasGang; delete spatialGang; delete rangeGang; delete baseGang; delete alphaGang; delete betaGang; delete saturation2Gang; delete noiseGang; delete multiplierGang; delete coneGang; delete rodGang; delete keyGang; delete phiGang; delete range2Gang; delete lowerGang; delete upperGang; delete brightnessGang; delete chromaticGang; delete lightGang; delete pregammagang;
+delete contrastfactorGang; delete saturationfactorGang; delete detailfactorGang; delete contrastGang; delete biasGang; delete spatialGang; delete rangeGang; delete baseGang; delete alphaGang; delete betaGang; delete saturation2Gang; delete noiseGang; delete multiplierGang; delete coneGang; delete rodGang; delete keyGang; delete phiGang; delete range2Gang; delete lowerGang; delete upperGang; delete brightnessGang; delete chromaticGang; delete lightGang; delete pregammagang;
 	//fetch original frame from hd
 	pfs::DOMIO pfsio;
 	OriginalPfsFrame=pfsio.readFrame( QFile::encodeName(cachepath+"/original.pfs").constData());
@@ -138,47 +123,54 @@ delete contrastfactorGang; delete saturationfactorGang; delete contrastGang; del
 	QFile::remove(cachepath+"/after_pregamma.pfs");
 }
 
-void TMWidget::mantiukReset() {
-contrastfactorGang->setDefault();
-saturationfactorGang->setDefault();
+void TMWidget::on_MantiukDefault_clicked() {
+	contrastfactorGang->setDefault();
+	saturationfactorGang->setDefault();
+	detailfactorGang->setDefault();
+	ContrastEqualizCheckBox->setChecked(false);
 }
-void TMWidget::ashikhminReset() {
-contrastGang->setDefault();
+void TMWidget::on_ashikhmin02Default_clicked() {
+	contrastGang->setDefault();
+	simpleCheckBox->setChecked(false);
+	eq2RadioButton->setChecked(true);
 }
-void TMWidget::dragoReset(){
-biasGang->setDefault();
+void TMWidget::on_drago03Default_clicked(){
+	biasGang->setDefault();
 }
-void TMWidget::durandReset(){
-spatialGang->setDefault();
-rangeGang->setDefault();
-baseGang->setDefault();
+void TMWidget::on_durand02Default_clicked(){
+	spatialGang->setDefault();
+	rangeGang->setDefault();
+	baseGang->setDefault();
 }
-void TMWidget::fattalReset(){
-alphaGang->setDefault();
-betaGang->setDefault();
-saturation2Gang->setDefault();
-noiseGang->setDefault();
-oldFattalCheckBox->setChecked(false);
+void TMWidget::on_fattal02Default_clicked(){
+	alphaGang->setDefault();
+	betaGang->setDefault();
+	saturation2Gang->setDefault();
+	noiseGang->setDefault();
+	oldFattalCheckBox->setChecked(false);
 }
-void TMWidget::pattanaikReset(){
-multiplierGang->setDefault();
-coneGang->setDefault();
-rodGang->setDefault();
+void TMWidget::on_pattanaik00Default_clicked(){
+	multiplierGang->setDefault();
+	coneGang->setDefault();
+	rodGang->setDefault();
+	pattalocal->setChecked(false);
+	autoYcheckbox->setChecked(false);
 }
-void TMWidget::reinhard02Reset(){
-keyGang->setDefault();
-phiGang->setDefault();
-range2Gang->setDefault();
-lowerGang->setDefault();
-upperGang->setDefault();
+void TMWidget::on_reinhard02Default_clicked(){
+	keyGang->setDefault();
+	phiGang->setDefault();
+	range2Gang->setDefault();
+	lowerGang->setDefault();
+	upperGang->setDefault();
+	usescalescheckbox->setChecked(false);
 }
-void TMWidget::reinhard05Reset(){
-brightnessGang->setDefault();
-chromaticGang->setDefault();
-lightGang->setDefault();
+void TMWidget::on_reinhard05Default_clicked(){
+	brightnessGang->setDefault();
+	chromaticGang->setDefault();
+	lightGang->setDefault();
 }
-void TMWidget::preGammaReset(){
-pregammagang->setDefault();
+void TMWidget::on_pregammadefault_clicked(){
+	pregammagang->setDefault();
 }
 
 MyProgressBar::MyProgressBar(QWidget *parent) : QProgressBar(parent) {
@@ -191,16 +183,15 @@ MyProgressBar::~MyProgressBar() {
 }
 
 void MyProgressBar::mousePressEvent(QMouseEvent *event) {
-	if (event->buttons()==Qt::LeftButton) {
+	if (event->buttons()==Qt::LeftButton)
 		emit leftMouseButtonClicked();
-	}
 }
 
 void MyProgressBar::advanceCurrentProgress() {
 	this->setValue(this->value()+1);
 }
 
-void TMWidget::apply_clicked() {
+void TMWidget::on_applyButton_clicked() {
 	FillToneMappingOptions();
 
 	MyProgressBar *newprogressbar=new MyProgressBar(sb);
@@ -223,40 +214,41 @@ void TMWidget::FillToneMappingOptions() {
 	ToneMappingOptions.xsize=sizes[sizeComboBox->currentIndex()];
 	ToneMappingOptions.pregamma=pregammagang->v();
 
-	QWidget *current_page=operators_tabWidget->currentWidget();
-	if (current_page==tab_mantiuk) {
+	QWidget *current_page=stackedWidget_operators->currentWidget();
+	if (current_page==page_mantiuk) {
 		ToneMappingOptions.tmoperator=mantiuk;
 		ToneMappingOptions.operator_options.mantiukoptions.contrastfactor=contrastfactorGang->v();
 		ToneMappingOptions.operator_options.mantiukoptions.saturationfactor=saturationfactorGang->v();
+		ToneMappingOptions.operator_options.mantiukoptions.detailfactor=detailfactorGang->v();
 		ToneMappingOptions.operator_options.mantiukoptions.contrastequalization=ContrastEqualizCheckBox->isChecked();
-	} else if (current_page==tab_fattal) {
+	} else if (current_page==page_fattal) {
 		ToneMappingOptions.tmoperator=fattal;
 		ToneMappingOptions.operator_options.fattaloptions.alpha=alphaGang->v();
 		ToneMappingOptions.operator_options.fattaloptions.beta=betaGang->v();
 		ToneMappingOptions.operator_options.fattaloptions.color=saturation2Gang->v();
 		ToneMappingOptions.operator_options.fattaloptions.noiseredux=noiseGang->v();
 		ToneMappingOptions.operator_options.fattaloptions.newfattal=!oldFattalCheckBox->isChecked();
-	} else if (current_page==tab_ashikhmin) {
+	} else if (current_page==page_ashikhmin) {
 		ToneMappingOptions.tmoperator=ashikhmin;
 		ToneMappingOptions.operator_options.ashikhminoptions.simple=simpleCheckBox->isChecked();
 		ToneMappingOptions.operator_options.ashikhminoptions.eq2=eq2RadioButton->isChecked();
 		ToneMappingOptions.operator_options.ashikhminoptions.lct=contrastGang->v();
-	} else if (current_page==tab_durand) {
+	} else if (current_page==page_durand) {
 		ToneMappingOptions.tmoperator=durand;
 		ToneMappingOptions.operator_options.durandoptions.spatial=spatialGang->v();
 		ToneMappingOptions.operator_options.durandoptions.range=rangeGang->v();
 		ToneMappingOptions.operator_options.durandoptions.base=baseGang->v();
-	} else if (current_page==tab_drago) {
+	} else if (current_page==page_drago) {
 		ToneMappingOptions.tmoperator=drago;
 		ToneMappingOptions.operator_options.dragooptions.bias=biasGang->v();
-	} else if (current_page==tab_pattanaik) {
+	} else if (current_page==page_pattanaik) {
 		ToneMappingOptions.tmoperator=pattanaik;
 		ToneMappingOptions.operator_options.pattanaikoptions.autolum=autoYcheckbox->isChecked();
 		ToneMappingOptions.operator_options.pattanaikoptions.local=pattalocal->isChecked();
 		ToneMappingOptions.operator_options.pattanaikoptions.cone=coneGang->v();
 		ToneMappingOptions.operator_options.pattanaikoptions.rod=rodGang->v();
 		ToneMappingOptions.operator_options.pattanaikoptions.multiplier=multiplierGang->v();
-	} else if (current_page==tab_reinhard02) {
+	} else if (current_page==page_reinhard02) {
 		ToneMappingOptions.tmoperator=reinhard02;
 		ToneMappingOptions.operator_options.reinhard02options.scales=usescalescheckbox->isChecked();
 		ToneMappingOptions.operator_options.reinhard02options.key=keyGang->v();
@@ -264,7 +256,7 @@ void TMWidget::FillToneMappingOptions() {
 		ToneMappingOptions.operator_options.reinhard02options.range=(int)range2Gang->v();
 		ToneMappingOptions.operator_options.reinhard02options.lower=(int)lowerGang->v();
 		ToneMappingOptions.operator_options.reinhard02options.upper=(int)upperGang->v();
-	} else if (current_page==tab_reinhard05) {
+	} else if (current_page==page_reinhard05) {
 		ToneMappingOptions.tmoperator=reinhard05;
 		ToneMappingOptions.operator_options.reinhard05options.brightness=brightnessGang->v();
 		ToneMappingOptions.operator_options.reinhard05options.chromaticAdaptation=chromaticGang->v();
@@ -272,8 +264,7 @@ void TMWidget::FillToneMappingOptions() {
 	}
 }
 
-
-void TMWidget::loadsettings() {
+void TMWidget::on_loadsettingsbutton_clicked() {
 	QString opened = QFileDialog::getOpenFileName(
 			this,
 			tr("Load a tonemapping settings text file..."),
@@ -292,11 +283,6 @@ void TMWidget::loadsettings() {
 		if (RecentPathLoadSaveTmoSettings != settings.value(KEY_RECENT_PATH_LOAD_SAVE_TMO_SETTINGS,QDir::currentPath()).toString()) {
 			settings.setValue(KEY_RECENT_PATH_LOAD_SAVE_TMO_SETTINGS, RecentPathLoadSaveTmoSettings);
 		}
-		//enable graphical elements
-		lineEditTMOsetting->setText(qfi.fileName());
-		lineEditTMOsetting->setEnabled(TRUE);
-		label_applyTMOSetting->setEnabled(TRUE);
-		button_fromTxt2Gui->setEnabled(TRUE);
 		//update filename internal field, used by parsing function fromTxt2Gui()
 		TMOSettingsFilename=opened;
 		//call parsing function
@@ -304,7 +290,7 @@ void TMWidget::loadsettings() {
 	}
 }
 
-void TMWidget::savesettings() {
+void TMWidget::on_savesettingsbutton_clicked() {
 	QString fname =QFileDialog::getSaveFileName(
 			this,
 			tr("Save tonemapping settings text file to..."),
@@ -321,13 +307,6 @@ void TMWidget::savesettings() {
 		if (RecentPathLoadSaveTmoSettings != settings.value(KEY_RECENT_PATH_LOAD_SAVE_TMO_SETTINGS, QDir::currentPath()).toString()) {
 			settings.setValue(KEY_RECENT_PATH_LOAD_SAVE_TMO_SETTINGS, RecentPathLoadSaveTmoSettings);
 		}
-		//enable graphical elements
-		lineEditTMOsetting->setText(QFileInfo(fname).fileName());
-		lineEditTMOsetting->setEnabled(TRUE);
-		label_applyTMOSetting->setEnabled(TRUE);
-		button_fromTxt2Gui->setEnabled(TRUE);
-		//update filename internal field, used by parsing function fromTxt2Gui()
-		TMOSettingsFilename=fname;
 		//write txt file
 		fromGui2Txt(fname);
 	}
@@ -346,40 +325,41 @@ void TMWidget::fromGui2Txt(QString destination) {
 	out << "# Please edit this file by hand only if you know what you're doing, in any case never change the left hand side text (i.e. the part before the ``='')." << endl;
 	out << "TMOSETTINGSVERSION=" << TMOSETTINGSVERSION << endl;
 
-	QWidget *current_page=operators_tabWidget->currentWidget();
-	if (current_page==tab_mantiuk) {
+	QWidget *current_page=stackedWidget_operators->currentWidget();
+	if (current_page==page_mantiuk) {
 		out << "TMO=" << "Mantiuk06" << endl;
 		out << "CONTRASTFACTOR=" << contrastfactorGang->v() << endl;
 		out << "SATURATIONFACTOR=" << saturationfactorGang->v() << endl;
+		out << "DETAILFACTOR=" << detailfactorGang->v() << endl;
 		out << "CONTRASTEQUALIZATION=" << (ContrastEqualizCheckBox->isChecked() ? "YES" : "NO") << endl;
-	} else if (current_page==tab_fattal) {
+	} else if (current_page==page_fattal) {
 		out << "TMO=" << "Fattal02" << endl;
 		out << "ALPHA=" << alphaGang->v() << endl;
 		out << "BETA=" << betaGang->v() << endl;
 		out << "COLOR=" << saturation2Gang->v() << endl;
 		out << "NOISE=" << noiseGang->v() << endl;
 		out << "OLDFATTAL=" << (oldFattalCheckBox->isChecked() ? "YES" : "NO") << endl;
-	} else if (current_page==tab_ashikhmin) {
+	} else if (current_page==page_ashikhmin) {
 		out << "TMO=" << "Ashikhmin02" << endl;
 		out << "SIMPLE=" << (simpleCheckBox->isChecked() ? "YES" : "NO") << endl;
 		out << "EQUATION=" << (eq2RadioButton->isChecked() ? "2" : "4") << endl;
 		out << "CONTRAST=" << contrastGang->v() << endl;
-	} else if (current_page==tab_durand) {
+	} else if (current_page==page_durand) {
 		out << "TMO=" << "Durand02" << endl;
 		out << "SPATIAL=" << spatialGang->v() << endl;
 		out << "RANGE=" << rangeGang->v() << endl;
 		out << "BASE=" << baseGang->v() << endl;
-	} else if (current_page==tab_drago) {
+	} else if (current_page==page_drago) {
 		out << "TMO=" << "Drago03" << endl;
 		out << "BIAS=" << biasGang->v() << endl;
-	} else if (current_page==tab_pattanaik) {
+	} else if (current_page==page_pattanaik) {
 		out << "TMO=" << "Pattanaik00" << endl;
 		out << "MULTIPLIER=" << multiplierGang->v() << endl;
 		out << "LOCAL=" << (pattalocal->isChecked() ? "YES" : "NO") << endl;
 		out << "AUTOLUMINANCE=" << (autoYcheckbox->isChecked() ? "YES" : "NO") << endl;
 		out << "CONE=" << coneGang->v() << endl;
 		out << "ROD=" << rodGang->v() << endl;
-	} else if (current_page==tab_reinhard02) {
+	} else if (current_page==page_reinhard02) {
 		out << "TMO=" << "Reinhard02" << endl;
 		out << "KEY=" << keyGang->v() << endl;
 		out << "PHI=" << phiGang->v() << endl;
@@ -387,7 +367,7 @@ void TMWidget::fromGui2Txt(QString destination) {
 		out << "RANGE=" << range2Gang->v() << endl;
 		out << "LOWER=" << lowerGang->v() << endl;
 		out << "UPPER=" << upperGang->v() << endl;
-	} else if (current_page==tab_reinhard05) {
+	} else if (current_page==page_reinhard05) {
 		out << "TMO=" << "Reinhard05" << endl;
 		out << "BRIGHTNESS=" << brightnessGang->v() << endl;
 		out << "CHROMATICADAPTATION=" << chromaticGang->v() << endl;
@@ -423,26 +403,28 @@ void TMWidget::fromTxt2Gui() {
 			}
 		} else if (field=="TMO") {
 			if (value=="Ashikhmin02") {
-				operators_tabWidget->setCurrentWidget(tab_ashikhmin);
+				stackedWidget_operators->setCurrentWidget(page_ashikhmin);
 			} else if (value == "Mantiuk06") {
-				operators_tabWidget->setCurrentWidget(tab_mantiuk);
+				stackedWidget_operators->setCurrentWidget(page_mantiuk);
 			} else if (value == "Drago03") {
-				operators_tabWidget->setCurrentWidget(tab_drago);
+				stackedWidget_operators->setCurrentWidget(page_drago);
 			} else if (value == "Durand02") {
-				operators_tabWidget->setCurrentWidget(tab_durand);
+				stackedWidget_operators->setCurrentWidget(page_durand);
 			} else if (value == "Fattal02") {
-				operators_tabWidget->setCurrentWidget(tab_fattal);
+				stackedWidget_operators->setCurrentWidget(page_fattal);
 			} else if (value == "Pattanaik00") {
-				operators_tabWidget->setCurrentWidget(tab_pattanaik);
+				stackedWidget_operators->setCurrentWidget(page_pattanaik);
 			} else if (value == "Reinhard02") {
-				operators_tabWidget->setCurrentWidget(tab_reinhard02);
+				stackedWidget_operators->setCurrentWidget(page_reinhard02);
 			} else if (value == "Reinhard05") {
-				operators_tabWidget->setCurrentWidget(tab_reinhard05);
+				stackedWidget_operators->setCurrentWidget(page_reinhard05);
 			}
 		} else if (field=="CONTRASTFACTOR") {
 			contrastFactorSlider->setValue(contrastfactorGang->v2p(value.toFloat()));
 		} else if (field=="SATURATIONFACTOR") {
 			saturationFactorSlider->setValue(saturationfactorGang->v2p(value.toFloat()));
+		} else if (field=="DETAILFACTOR") {
+			detailFactorSlider->setValue(detailfactorGang->v2p(value.toFloat()));
 		} else if (field=="CONTRASTEQUALIZATION") {
 			ContrastEqualizCheckBox->setChecked((value=="YES"));
 		} else if (field=="SIMPLE") {
@@ -502,38 +484,22 @@ void TMWidget::fromTxt2Gui() {
 			pregammaSlider->setValue(pregammagang->v2p(value.toFloat()));
 		}
 	}
-	apply_clicked();
+// 	on_applyButton_clicked();
 }
 
-void TMWidget::keyPressEvent(QKeyEvent* event) {
-	if (!adding_custom_size)
-		return;
-	if (event->key() == Qt::Key_Enter || event->key()==Qt::Key_Return) {
-		int value=(sizeComboBox->lineEdit()->text()).toInt();
-		if (value>0) {
-			sizes.push_front(value);
-		}
-		sizeComboBox->setEditable(false);
-		pregammaGroup->setDisabled(false);
-		operators_tabWidget->setDisabled(false);
-		applyButton->setDisabled(false);
-		groupSaveLoadTMOsetting->setDisabled(false);
-		addCustomSizeButton->setDisabled(false);
-		adding_custom_size=false;
-		for(int i = 0; i < sizes.size(); i++) {
-			sizeComboBox->addItem( QString("%1x%2").arg(sizes[i]).arg( (int)(HeightWidthRatio*sizes[i]) ));
-		}
+void TMWidget::on_addCustomSizeButton_clicked(){
+	bool ok;
+	int i = QInputDialog::getInteger(this, tr("Custom LDR size"),
+	                                      tr("Enter the width of the new size:"), 0 , 0, 2147483647, 1, &ok);
+	if (ok && i > 0) {
+		sizes.push_front(i);
+		fillCustomSizeComboBox();
 	}
 }
 
-void TMWidget::addCustomSize(){
+void TMWidget::fillCustomSizeComboBox() {
 	sizeComboBox->clear();
-	sizeComboBox->setEditable(true);
-	pregammaGroup->setDisabled(true);
-	operators_tabWidget->setDisabled(true);
-	applyButton->setDisabled(true);
-	groupSaveLoadTMOsetting->setDisabled(true);
-	addCustomSizeButton->setDisabled(true);
-	adding_custom_size=true;
-	sizeComboBox->lineEdit()->setFocus();
+	for(int i = 0; i < sizes.size(); i++)
+		sizeComboBox->addItem( QString("%1x%2").arg(sizes[i]).arg( (int)(HeightWidthRatio*sizes[i]) ));
 }
+
