@@ -1,8 +1,8 @@
 /**
  * This file is a part of Qtpfsgui package.
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  * Copyright (C) 2006,2007 Giuseppe Rota
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- * ---------------------------------------------------------------------- 
+ * ----------------------------------------------------------------------
  *
  * @author Giuseppe Rota <grota@users.sourceforge.net>
  */
@@ -41,10 +41,13 @@ int main( int argc, char ** argv )
 	// FIXME: the problem is that some args are supplied when
 	// running as a gui-app in Mac OS X, this messes up things.
 	if (argc>1) {
-		QCoreApplication CLIapplication( argc, argv );
+		QCoreApplication cliApplication( argc, argv );
+		QTranslator translator;
+		translator.load(QString("lang_") + QtpfsguiOptions::getInstance()->gui_lang, I18NDIR);
+		cliApplication.installTranslator(&translator);
 		CommandLineInterfaceManager cli( argc, argv );
-		CLIapplication.connect(&cli, SIGNAL(finishedParsing()), &CLIapplication, SLOT(quit()));
-		rc=CLIapplication.exec();
+		cliApplication.connect(&cli, SIGNAL(finishedParsing()), &cliApplication, SLOT(quit()));
+		rc = cliApplication.exec();
 		QtpfsguiOptions::deleteInstance();
 		return rc;
 	}
